@@ -14,7 +14,7 @@ use Class::Accessor::Lite (
     rw => [ qw/max_workers spawn_interval err_respawn_interval trap_signals signal_received manager_pid on_child_reap before_fork after_fork/ ],
 );
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 sub new {
     my $klass = shift;
@@ -220,6 +220,7 @@ sub _wait {
         my $sleep_secs = min grep { defined $_ } (
             $delayed_task_sleep,
             $delayed_fork_sleep,
+            $self->_max_wait(),
         );
         if (defined $sleep_secs) {
             # wait max sleep_secs or until signalled
@@ -236,6 +237,10 @@ sub _wait {
     }
 }
 
+sub _max_wait {
+    return undef;
+}
+
 1;
 
 __END__
